@@ -5,7 +5,7 @@ package Test::Sah::Schema;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Test-Sah-Schema'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -91,7 +91,11 @@ sub sah_schema_module_ok {
                             ($eg->{name} ? " ($eg->{name})" :
                              ($eg->{summary} ? " ($eg->{summary})" : "")),
                         sub {
-                            my ($errmsg, $res)  = @{ $vdr->($eg->{value}) };
+                            my $value =
+                                exists $eg->{value} ? $eg->{value} :
+                                exists $eg->{data}  ? $eg->{data} : die "BUG in example #$i: Please specify 'value' or 'data'";
+
+                                my ($errmsg, $res)  = @{ $vdr->($value) };
                             if ($eg->{valid}) {
                                 if ($errmsg) {
                                     $Test->ok(0, "Data should be valid, but isn't");
@@ -254,7 +258,7 @@ Test::Sah::Schema - Test Sah::Schema::* modules in distribution
 
 =head1 VERSION
 
-This document describes version 0.003 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
+This document describes version 0.004 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
